<?php

namespace Drupal\tag1quo\Form;

use Drupal\Core\Form\ConfigFormBase;
use Drupal\Core\Form\FormStateInterface;

class Tag1quoAdminSettings extends ConfigFormBase {

  /**
   * {@inheritdoc}
   */
  public function getFormId() {
    return 'tag1quo_admin_settings';
  }

  /**
   * {@inheritdoc}
   */
  public function submitForm(array &$form, FormStateInterface $form_state) {

    foreach (['tag1quo_report', 'tag1quo_token', 'tag1quo_debug'] as $variable) {
      $this->config('tag1quo.settings')->set($variable, $form_state->getValue($variable));
    }
    $this->config('tag1quo.settings')->save();

    parent::submitForm($form, $form_state);
  }

  /**
   * {@inheritdoc}
   */
  protected function getEditableConfigNames() {
    return ['tag1quo.settings'];
  }

  public function buildForm(array $form, FormStateInterface $form_state) {
    $form['tag1quo_report'] = [
      '#type' => 'checkbox',
      '#title' => t('Report information to Tag1 Quo'),
      '#description' => t('When checked, this module will send information about your website to Tag1 Quo, a paid service.'),
      '#default_value' => $this->config('tag1quo.settings')->get('tag1quo_report'),
    ];
    if ($this->config('tag1quo.settings')->get('tag1quo_report') && $this->config('tag1quo.settings')->get('tag1quo_token') === '') {
      drupal_set_message('No information will be sent to Tag1 Quo until you configure your token.', 'warning');
    }
    $form['tag1quo_token'] = [
      '#type' => 'textfield',
      '#title' => t('Token'),
      '#description' => t('Your secure login token for the Tag1 Quo'),
      '#default_value' => $this->config('tag1quo.settings')->get('tag1quo_token'),
      '#maxlength' => 255,
    ];
    $form['advanced'] = [
      '#type' => 'details',
      '#title' => t('Advanced'),
      '#open' => $this->config('tag1quo.settings')->get('tag1quo_debug'),
    ];
    $form['advanced']['tag1quo_token'] = [
      '#value' => '<div class="container-inline"><span class="option">' . t('Site identifier') . '</span><br /><span class="description">' . \Drupal::state()->get('tag1quo_siteid') . '</span></div>'
      ];
    $form['advanced']['tag1quo_debug'] = [
      '#type' => 'checkbox',
      '#title' => t('Debug logging'),
      '#description' => t('When checked, writes verbose watchdog logs for all communication attempts.'),
      '#default_value' => $this->config('tag1quo.settings')->get('tag1quo_debug'),
    ];

    return parent::buildForm($form, $form_state);
  }

  public function validateForm(array &$form, FormStateInterface $form_state) {
    $token = $form_state->getValue('tag1quo_token');
    $tag1quo_report = $form_state->getValue('tag1quo_report');

    // If not enabled, don't bother with other validation.
    if (!$tag1quo_report) {
      return;
    }

    if (empty($token)) {
      $form_state->setErrorByName('tag1quo_token', t('The token field must not be empty'));
    }
    else {
      $result = tag1quo_send_report($token, $tag1quo_report);
      if ($result !== TAG1QUO_SUCCESS) {
        $form_state->setErrorByName('tag1quo_token', t('Failed to validate token with server. Full details of the transaction are in the system log.'));
      }
      else {
        drupal_set_message(t('Successfully validated token and communicated with Tag1 Quo Server.'));
      }
    }
  }

}
